==> mzanalytics_mybmw-0.0.6.tar.gz: lib/mzanalytics_ios.dart <==
import 'dart:async';
import 'package:flutter/services.dart';

class Mzanalytics_ios {
  static const MethodChannel _channel =
      const MethodChannel('mzanalytics_mybmw');

  static Future<void> appid(String aid) async {
    try {
      _channel.invokeMethod('appid', {'appid': aid});
    } on PlatformException {}
  }

  static Future<void> trackPageView(var parameter) async {
    try {
      _channel.invokeMethod('trackPageView', parameter);
    } on PlatformException {}
  }

  static Future<void> trackEvent(var parameter) async {
    try {
      _channel.invokeMethod('trackEvent', parameter);
    } on PlatformException {}
  }

  static Future<void> trackSiteCustomEvent(var parameter) async {
    try {
      _channel.invokeMethod('trackSiteCustomEvent', parameter);
    } on PlatformException {}
  }

  static Future<void> get trackPulse async {
    try {
      _channel.invokeMethod('trackPulse');
    } on PlatformException {}
  }

  static Future<String> get getCid async {
    try {
      final String cid = await _channel.invokeMethod('getCid');
      return cid;
    } on PlatformException {}
  }

  static Future<void> setEnableLog(bool parameter) async {
    try {
      _channel.invokeMethod('setEnableLog', {'Enable': parameter});
    } on PlatformException {}
  }

  static Future<void> handleOpenURL(String url) async {
    try {
      _channel.invokeMethod('handleOpenURL', {'url': url});
    } on PlatformException {}
  }

  static Future<void> setCd(var key, var value) async {
    try {
      _channel.invokeMethod(
          'setCd', <String, dynamic>{'cd_key': key, "cd_value": value});
    } on PlatformException {}
  }

  static Future<void> setCm(var key, var value) async {
    try {
      _channel.invokeMethod(
          'setCm', <String, dynamic>{'cm_key': key, "cm_value": value});
    } on PlatformException {}
  }

  static Future<void> deleteCd(var key) async {
    try {
      return _channel
          .invokeMethod('deleteCd', <String, dynamic>{'cd_key': key});
    } on PlatformException {}
  }

  static Future<void> deleteCm(var key) async {
    try {
      return _channel
          .invokeMethod('deleteCm', <String, dynamic>{'cm_key': key});
    } on PlatformException {}
  }

  static Future<Map> getCdAndCm() async {
    try {
      return _channel.invokeMethod('getCdAndCm');
    } on PlatformException {}
  }

  static Future<bool> isAutoTrackpage() async {
    try {
      return _channel.invokeMethod('isAutoTrackpage');
    } on PlatformException {}
  }

  static Future<List> getBlackList() async {
    try {
      return _channel.invokeMethod('getBlackList');
    } on PlatformException {}
  }
}

==> mzanalytics_mybmw-0.2.3.tar.gz: lib/mzanalytics_ios.dart <==
import 'dart:async';
import 'package:flutter/services.dart';

class mzanalytics_ios {
  static const MethodChannel _channel =
      const MethodChannel('mzanalytics_mybmw');

  static Future<void> appid(String aid) async {
    try {
      _channel.invokeMethod('appid', {'appid': aid});
    } on PlatformException {}
  }

  static Future<void> trackPageView(var parameter) async {
    try {
      _channel.invokeMethod('trackPageView', parameter);
    } on PlatformException {}
  }

  static Future<void> trackEvent(var parameter) async {
    try {
      _channel.invokeMethod('trackEvent', parameter);
    } on PlatformException {}
  }

  static Future<void> trackSiteCustomEvent(var parameter) async {
    try {
      _channel.invokeMethod('trackSiteCustomEvent', parameter);
    } on PlatformException {}
  }

  static Future<void> trackPulse() async {
    try {
      _channel.invokeMethod('trackPulse');
    } on PlatformException {}
  }

  static Future<String> getCid() async {
    try {
      final String cid = await _channel.invokeMethod('getCid');
      return cid;
    } on PlatformException {}
  }

  static Future<void> setEnableLog(bool parameter) async {
    try {
      _channel.invokeMethod('setEnableLog', {'Enable': parameter});
    } on PlatformException {}
  }

  static Future<void> handleOpenURL(String url) async {
    try {
      _channel.invokeMethod('handleOpenURL', {'url': url});
    } on PlatformException {}
  }

  static Future<void> setCd(var key, var value) async {
    try {
      _channel.invokeMethod(
          'setCd', <String, dynamic>{'cd_key': key, "cd_value": value});
    } on PlatformException {}
  }

  static Future<void> setCm(var key, var value) async {
    try {
      _channel.invokeMethod(
          'setCm', <String, dynamic>{'cm_key': key, "cm_value": value});
    } on PlatformException {}
  }

  static Future<void> deleteCd(var key) async {
    try {
      return _channel
          .invokeMethod('deleteCd', <String, dynamic>{'cd_key': key});
    } on PlatformException {}
  }

  static Future<void> deleteCm(var key) async {
    try {
      return _channel
          .invokeMethod('deleteCm', <String, dynamic>{'cm_key': key});
    } on PlatformException {}
  }

  static Future<Map> getCdAndCm() async {
    try {
      return _channel.invokeMethod('getCdAndCm');
    } on PlatformException {}
  }

  static Future<bool> isAutoTrackpage() async {
    try {
      return _channel.invokeMethod('isAutoTrackpage');
    } on PlatformException {}
  }

  static Future<List> getBlackList() async {
    try {
      return _channel.invokeMethod('getBlackList');
    } on PlatformException {}
  }
}
